@@ -2,6 +2,7 @@ from citrination_client.base.base_client import BaseClient
 from citrination_client.base.errors import *
 from citrination_client.data import *
 from citrination_client.data import routes as routes
+from citrination_client.data.ingest import IngestClient
 
 from pypif import pif
 
@@ -28,6 +29,8 @@ class DataClient(BaseClient):
         """
         members = [
             "upload",
+            "upload_with_ingester",
+            "list_ingesters",
             "list_files",
             "matched_file_count",
             "get_dataset_files",
@@ -35,14 +38,26 @@ class DataClient(BaseClient):
             "download_files",
             "create_dataset",
             "create_dataset_version",
-            "get_ingest_status"
+            "get_ingest_status",
+            "get_pif",
+            "update_dataset",
+            "delete_dataset",
+            "get_data_view_ids"
         ]
-        super(DataClient, self).__init__(api_key, host, members, suppress_warnings, proxies)
+        super(DataClient, self).__init__(
+            api_key, host, members, suppress_warnings, proxies
+        )
+        self._ingest = IngestClient(
+            api_key, host, suppress_warnings, proxies
+        )
 
     def upload(self, dataset_id, source_path, dest_path=None):
         """
-        Upload a file, specifying source and dest paths a file (acts as the scp command).asdfasdf
+        Upload a file, specifying source and optionally destination paths of a
+        file (acts as the scp command)
 
+        :param dataset_id: The ID of the dataset to search for files.
+        :type dataset_id: Union[int, str]
         :param source_path: The path to the file on the source host asdf
         :type source_path: str
         :param dest_path: The path to the file where the contents of the upload will be written (on the dest host)
@@ -56,27 +71,48 @@ class DataClient(BaseClient):
             dest_path = source_path
         else:
             dest_path = str(dest_path)
+
         if os.path.isdir(source_path):
             for path, subdirs, files in os.walk(source_path):
                 relative_path = os.path.relpath(path, source_path)
                 current_dest_prefix = dest_path
                 if relative_path is not ".":
-                    current_dest_prefix = os.path.join(current_dest_prefix, relative_path)
+                    current_dest_prefix = os.path.join(
+                        current_dest_prefix, relative_path
+                    )
                 for name in files:
                     current_dest_path = os.path.join(current_dest_prefix, name)
                     current_source_path = os.path.join(path, name)
                     try:
-                        if self.upload(dataset_id, current_source_path, current_dest_path).successful():
-                            upload_result.add_success(current_source_path)
+                        file_upload_result = self.upload(
+                            dataset_id, current_source_path, current_dest_path
+                        )
+                        if file_upload_result.successful():
+                            file_id = file_upload_result.successes[0]['id']
+                            upload_result.add_success(
+                                current_source_path, file_id, current_dest_path
+                            )
                         else:
-                            upload_result.add_failure(current_source_path,"Upload failure")
+                            upload_result.add_failure(
+                                current_source_path, "Upload failure"
+                            )
                     except (CitrinationClientError, ValueError) as e:
                         upload_result.add_failure(current_source_path, str(e))
+
             return upload_result
+
         elif os.path.isfile(source_path):
-            file_data = { "dest_path": str(dest_path), "src_path": str(source_path)}
-            j = self._get_success_json(self._post_json(routes.upload_to_dataset(dataset_id), data=file_data))
-            s3url = _get_s3_presigned_url(j)
+            path_data = {
+                "dest_path": str(dest_path),
+                "src_path": str(source_path)
+            }
+            file_data = self._get_success_json(
+                self._post_json(
+                    routes.upload_to_dataset(dataset_id), data = path_data
+                )
+            )
+            s3url = _get_s3_presigned_url(file_data)
+
             with open(source_path, 'rb') as f:
                 if os.stat(source_path).st_size == 0:
                     # Upload a null character as a placeholder for
@@ -85,17 +121,95 @@ class DataClient(BaseClient):
                     data = "\0"
                 else:
                     data = f
-                r = requests.put(s3url, data=data, headers=j["required_headers"])
-                if r.status_code == 200:
-                    data = {'s3object': j['url']['path'], 's3bucket': j['bucket']}
-                    self._post_json(routes.update_file(j['file_id']), data=data)
-                    upload_result.add_success(source_path)
+
+                s3_response = requests.put(
+                    s3url,
+                    data = data,
+                    headers = file_data["required_headers"],
+                    proxies = self.proxies
+                )
+                if s3_response.status_code == 200:
+                    data = {
+                        's3object': file_data['url']['path'],
+                        's3bucket': file_data['bucket']
+                    }
+                    self._post_json(
+                        routes.update_file(file_data['file_id']), data = data
+                    )
+                    upload_result.add_success(
+                        source_path, file_data['file_id'], path_data["dest_path"]
+                    )
                     return upload_result
                 else:
-                    raise CitrinationClientError("Failure to upload {} to Citrination".format(source_path))
+                    raise CitrinationClientError(
+                        "Failure to upload {} to Citrination".format(source_path)
+                    )
+
         else:
             raise ValueError("No file at specified path {}".format(source_path))
 
+    def upload_with_ingester(self, dataset_id, source_path, ingester, ingester_arguments=[], dest_path=None):
+        """
+        Upload a file using a particular ingester, specifying source and
+        optionally destination paths of a file (acts as the scp command)
+
+        :param dataset_id: The ID of the dataset to search for files.
+        :type dataset_id: Union[int, str]
+        :param source_path: The path to the file on the source host asdf
+        :type source_path: str
+        :param ingester: The ingester being used
+        :type ingester: class:`citrination_client.data.ingest.Ingester`
+        :param ingester_arguments: ingester arguments (optional), arguments should
+                                   contain keys "name" and "value"
+        :type ingester_arguments: list of dict
+        :param dest_path: The path to the file where the contents of the upload will be written (on the dest host)
+        :type dest_path: str
+        :return: The result of the upload process
+        :rtype: :class:`UploadResult`
+        """
+        if not os.path.isfile(source_path):
+            raise ValueError("source_path parameter must point to a file".format(source_path))
+
+        self._ingest.validate_ingester(ingester, ingester_arguments)
+        file_upload_result = self.upload(dataset_id, source_path, dest_path)
+
+        if len(file_upload_result.successes) == 1:
+            file_path = file_upload_result.successes[0]["dest_path"]
+            self._ingest.submit(dataset_id, file_path, ingester, ingester_arguments)
+
+        return file_upload_result
+
+    def upload_with_template_csv_ingester(self, dataset_id, source_path, dest_path=None):
+        """
+        Upload a file using the template CSV ingester, specifying source and
+        optionally destination paths of a file (acts as the scp command)
+
+        :param dataset_id: The ID of the dataset to search for files.
+        :type dataset_id: Union[int, str]
+        :param source_path: The path to the file on the source host asdf
+        :type source_path: str
+        :param dest_path: The path to the file where the contents of the upload will be written (on the dest host)
+        :type dest_path: str
+        :return: The result of the upload process
+        :rtype: :class:`UploadResult`
+        """
+        template_csv_ingester = self.list_ingesters().find_by_id(
+            "citrine/ingest template_csv_converter"
+        )
+
+        return self.upload_with_ingester(
+            dataset_id, source_path, template_csv_ingester, dest_path=dest_path
+        )
+
+    def list_ingesters(self):
+        """
+        Retrieves the list of available ingesters
+
+        :return: The list of ingesters available for ingestion
+        :rtype: :class:`IngesterList`
+        """
+        return self._ingest.list_ingesters()
+
     def list_files(self, dataset_id, glob=".", is_dir=False):
         """
         List matched filenames in a dataset on Citrination.
@@ -142,10 +256,13 @@ class DataClient(BaseClient):
         :return: Status of dataset ingestion as a string
         """
         failure_message = "Failed to create dataset ingest status for dataset {}".format(dataset_id)
-        status = self._get_success_json(
-            self._post_json('v1/datasets/'+str(dataset_id)+'/ingest-status', data={},
-                            failure_message=failure_message))['data']['status']
-        return status
+        response = self._get_success_json(
+            self._get('v1/datasets/' + str(dataset_id) + '/ingest-status',
+                            failure_message=failure_message))['data']
+
+        if 'status' in response:
+            return response['status']
+        return ''
 
     def get_dataset_files(self, dataset_id, glob=".", is_dir=False, version_number=None):
         """
@@ -232,7 +349,7 @@ class DataClient(BaseClient):
             if not os.path.isdir(os.path.dirname(local_path)):
                 os.makedirs(os.path.dirname(local_path))
 
-            r = requests.get(f.url, stream=True)
+            r = requests.get(f.url, stream=True, proxies = self.proxies)
 
             with open(local_path, 'wb') as output_file:
                 shutil.copyfileobj(r.raw, output_file)
@@ -254,7 +371,7 @@ class DataClient(BaseClient):
         if dataset_version == None:
             response = self._get(routes.pif_dataset_uid(dataset_id, uid), failure_message=failure_message)
         else:
-            response = self._get(routes.pif_dataset_version_uid(dataset_id, uid, dataset_version), failure_message=failure_message)
+            response = self._get(routes.pif_dataset_version_uid(dataset_id, dataset_version, uid), failure_message=failure_message)
 
         return pif.loads(response.content.decode("utf-8"))
 
@@ -315,6 +432,15 @@ class DataClient(BaseClient):
 
         return _dataset_from_response_dict(response)
 
+    def delete_dataset(self, dataset_id):
+        """
+        Delete a dataset by id.  This will only work if you are the owner of the dataset.
+
+        :param dataset_id: The ID of the dataset to data.
+        """
+        failure_message = "Dataset delete failed"
+        self._delete('v1/datasets/' + str(dataset_id), None, failure_message=failure_message)
+
     def create_dataset_version(self, dataset_id):
         """
         Create a new data set version.
@@ -329,6 +455,22 @@ class DataClient(BaseClient):
 
         return DatasetVersion(number=number)
 
+    def get_data_view_ids(self, dataset_id):
+        """
+        Returns a list of ids for data views that are built upon the provided dataset.
+
+        :param dataset_id: The ID of the dataset for which the version must be bumped.
+        :type dataset_id: int
+        :return: The list of data view ids that use the given dataset.
+        :rtype: list of int
+        """
+        failure_message = "Failed to get data view ids for dataset {}".format(dataset_id)
+        return self._get_success_json(
+            self._get(
+                routes.get_data_view_ids_path(dataset_id), failure_message=failure_message
+            )
+        )['data']
+
 def _dataset_from_response_dict(dataset):
     return Dataset(dataset['id'], name=dataset['name'],
         description=dataset['description'], created_at=dataset['created_at'])
