@@ -7,17 +7,19 @@ class ClassificationQuery(BaseObjectQuery):
     Class to query against a PIF Classification object.
     """
     
-    def __init__(self, logic=None, simple=None, extract_as=None, extract_all=None,extract_when_missing=None, 
-                 tags=None, length=None, offset=None, name=None, value=None, query=None, **kwargs):
+    def __init__(self, logic=None, weight=None, simple=None, simple_weight=None, extract_as=None, extract_all=None,
+                 extract_when_missing=None, tags=None, length=None, offset=None, name=None, value=None,
+                 query=None, **kwargs):
         """
         Constructor.
         
         :param logic: Logic for this filter. Must be equal to one of "MUST", "MUST_NOT", "SHOULD", or "OPTIONAL".
+        :param weight: Weight of the query.
         :param simple: String with the simple query against all fields.
+        :param simple_weight: Dictionary of relative paths to their weights for simple queries.
         :param extract_as: String with the alias to save this field under.
         :param extract_all: Boolean setting whether all values in an array should be extracted.
-        :param extract_when_missing: Any valid JSON-supported object or PIF object. This value is returned when a value
-        is missing that should be extracted (and the overall query is still satisfied).
+        :param extract_when_missing: Any valid JSON-supported object or PIF object. This value is returned when a value is missing that should be extracted (and the overall query is still satisfied).
         :param tags: One or more :class:`FieldQuery` operations against the tags field.
         :param length: One or more :class:`FieldQuery` operations against the length field.
         :param offset: One or more :class:`FieldQuery` operations against the offset field.
@@ -26,8 +28,9 @@ class ClassificationQuery(BaseObjectQuery):
         :param query: One or more :class:`ClassificationQuery` objects for nested queries.
         """
         super(ClassificationQuery, self).__init__(
-            logic=logic, simple=simple, extract_as=extract_as, extract_all=extract_all,
-            extract_when_missing=extract_when_missing, tags=tags, length=length, offset=offset, **kwargs)
+            logic=logic, weight=weight, simple=simple, simple_weight=simple_weight, extract_as=extract_as,
+            extract_all=extract_all, extract_when_missing=extract_when_missing, tags=tags, length=length,
+            offset=offset, **kwargs)
         self._name = None
         self.name = name
         self._value = None
